# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    AddChapterResponseModel,
    AddKnowledgeBaseResponseModel,
    AddProjectRequest,
    AddProjectResponseModel,
    AddPronunciationDictionaryResponseModel,
    AddPronunciationDictionaryResponseModelPermissionOnResource,
    AddSharingVoiceRequest,
    AddVoiceIvcResponseModel,
    AddVoiceResponseModel,
    AddWorkspaceGroupMemberResponseModel,
    AddWorkspaceInviteResponseModel,
    AdditionalFormatResponseModel,
    AdditionalFormats,
    Age,
    AgentCallLimits,
    AgentConfig,
    AgentConfigOverride,
    AgentConfigOverrideConfig,
    AgentMetadataResponseModel,
    AgentPlatformSettingsRequestModel,
    AgentPlatformSettingsResponseModel,
    AgentSimulatedChatTestResponseModel,
    AgentSummaryResponseModel,
    AgentTestingSettings,
    AgentTransfer,
    AgentWorkspaceOverridesInput,
    AgentWorkspaceOverridesOutput,
    Alignment,
    AllowlistItem,
    ArrayJsonSchemaPropertyInput,
    ArrayJsonSchemaPropertyInputItems,
    ArrayJsonSchemaPropertyOutput,
    ArrayJsonSchemaPropertyOutputItems,
    AsrConversationalConfig,
    AsrInputFormat,
    AsrProvider,
    AsrQuality,
    AudioNativeCreateProjectResponseModel,
    AudioNativeEditContentResponseModel,
    AudioNativeProjectSettingsResponseModel,
    AudioNativeProjectSettingsResponseModelStatus,
    AudioOutput,
    AudioOutputMulti,
    AudioWithTimestampsResponse,
    AuthConnectionLocator,
    AuthSettings,
    AuthorizationMethod,
    BadRequestErrorBody,
    BanReasonType,
    BatchCallDetailedResponse,
    BatchCallRecipientStatus,
    BatchCallResponse,
    BatchCallStatus,
    BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostAge,
    BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostGender,
    BreakdownTypes,
    BuiltInToolsInput,
    BuiltInToolsOutput,
    CaptionStyleCharacterAnimationModel,
    CaptionStyleCharacterAnimationModelEnterType,
    CaptionStyleCharacterAnimationModelExitType,
    CaptionStyleHorizontalPlacementModel,
    CaptionStyleHorizontalPlacementModelAlign,
    CaptionStyleModel,
    CaptionStyleModelTextAlign,
    CaptionStyleModelTextStyle,
    CaptionStyleModelTextWeight,
    CaptionStyleSectionAnimationModel,
    CaptionStyleSectionAnimationModelEnterType,
    CaptionStyleSectionAnimationModelExitType,
    CaptionStyleTemplateModel,
    CaptionStyleVerticalPlacementModel,
    CaptionStyleVerticalPlacementModelAlign,
    CaptionStyleWordAnimationModel,
    CaptionStyleWordAnimationModelEnterType,
    CaptionStyleWordAnimationModelExitType,
    ChapterContentBlockExtendableNodeResponseModel,
    ChapterContentBlockInputModel,
    ChapterContentBlockInputModelSubType,
    ChapterContentBlockResponseModel,
    ChapterContentBlockResponseModelNodesItem,
    ChapterContentBlockResponseModelNodesItem_Other,
    ChapterContentBlockResponseModelNodesItem_TtsNode,
    ChapterContentBlockTtsNodeResponseModel,
    ChapterContentInputModel,
    ChapterContentParagraphTtsNodeInputModel,
    ChapterContentResponseModel,
    ChapterResponse,
    ChapterSnapshotExtendedResponseModel,
    ChapterSnapshotResponse,
    ChapterSnapshotsResponse,
    ChapterState,
    ChapterStatisticsResponse,
    ChapterWithContentResponseModel,
    ChapterWithContentResponseModelState,
    CharacterAlignmentModel,
    CharacterAlignmentResponseModel,
    CharacterUsageResponse,
    ClientEvent,
    ClientToolConfigInput,
    ClientToolConfigOutput,
    CloseConnection,
    CloseContext,
    CloseSocket,
    ConvAiDynamicVariable,
    ConvAiSecretLocator,
    ConvAiStoredSecretDependencies,
    ConvAiStoredSecretDependenciesAgentsItem,
    ConvAiStoredSecretDependenciesAgentsItem_Available,
    ConvAiStoredSecretDependenciesAgentsItem_Unknown,
    ConvAiStoredSecretDependenciesToolsItem,
    ConvAiStoredSecretDependenciesToolsItem_Available,
    ConvAiStoredSecretDependenciesToolsItem_Unknown,
    ConvAiUserSecretDbModel,
    ConvAiWebhooks,
    ConvAiWorkspaceStoredSecretConfig,
    ConversationChargingCommonModel,
    ConversationConfig,
    ConversationConfigClientOverrideConfigInput,
    ConversationConfigClientOverrideConfigOutput,
    ConversationConfigClientOverrideInput,
    ConversationConfigClientOverrideOutput,
    ConversationConfigOverride,
    ConversationConfigOverrideConfig,
    ConversationDeletionSettings,
    ConversationHistoryAnalysisCommonModel,
    ConversationHistoryBatchCallModel,
    ConversationHistoryElevenAssistantCommonModel,
    ConversationHistoryErrorCommonModel,
    ConversationHistoryEvaluationCriteriaResultCommonModel,
    ConversationHistoryFeedbackCommonModel,
    ConversationHistoryMetadataCommonModel,
    ConversationHistoryMetadataCommonModelPhoneCall,
    ConversationHistoryMetadataCommonModelPhoneCall_SipTrunking,
    ConversationHistoryMetadataCommonModelPhoneCall_Twilio,
    ConversationHistoryRagUsageCommonModel,
    ConversationHistorySipTrunkingPhoneCallModel,
    ConversationHistorySipTrunkingPhoneCallModelDirection,
    ConversationHistoryTranscriptCommonModelInput,
    ConversationHistoryTranscriptCommonModelInputRole,
    ConversationHistoryTranscriptCommonModelInputSourceMedium,
    ConversationHistoryTranscriptCommonModelInputToolResultsItem,
    ConversationHistoryTranscriptCommonModelOutput,
    ConversationHistoryTranscriptCommonModelOutputRole,
    ConversationHistoryTranscriptCommonModelOutputSourceMedium,
    ConversationHistoryTranscriptCommonModelOutputToolResultsItem,
    ConversationHistoryTranscriptOtherToolsResultCommonModel,
    ConversationHistoryTranscriptOtherToolsResultCommonModelType,
    ConversationHistoryTranscriptSystemToolResultCommonModel,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_EndCallSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_LanguageDetectionSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfError,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_SkipTurnSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentError,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberError,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberSipSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberTwilioSuccess,
    ConversationHistoryTranscriptSystemToolResultCommonModelResult_VoicemailDetectionSuccess,
    ConversationHistoryTranscriptToolCallClientDetails,
    ConversationHistoryTranscriptToolCallCommonModel,
    ConversationHistoryTranscriptToolCallCommonModelToolDetails,
    ConversationHistoryTranscriptToolCallCommonModelToolDetails_Client,
    ConversationHistoryTranscriptToolCallCommonModelToolDetails_Mcp,
    ConversationHistoryTranscriptToolCallCommonModelToolDetails_Webhook,
    ConversationHistoryTranscriptToolCallMcpDetails,
    ConversationHistoryTranscriptToolCallWebhookDetails,
    ConversationHistoryTranscriptWorkflowToolsResultCommonModelInput,
    ConversationHistoryTranscriptWorkflowToolsResultCommonModelOutput,
    ConversationHistoryTwilioPhoneCallModel,
    ConversationHistoryTwilioPhoneCallModelDirection,
    ConversationInitiationClientDataConfigInput,
    ConversationInitiationClientDataConfigOutput,
    ConversationInitiationClientDataInternal,
    ConversationInitiationClientDataInternalDynamicVariablesValue,
    ConversationInitiationClientDataRequestInput,
    ConversationInitiationClientDataRequestInputDynamicVariablesValue,
    ConversationInitiationClientDataRequestOutput,
    ConversationInitiationClientDataRequestOutputDynamicVariablesValue,
    ConversationInitiationClientDataWebhook,
    ConversationInitiationClientDataWebhookRequestHeadersValue,
    ConversationInitiationSource,
    ConversationInitiationSourceInfo,
    ConversationSignedUrlResponseModel,
    ConversationSimulationSpecification,
    ConversationSimulationSpecificationDynamicVariablesValue,
    ConversationSummaryResponseModel,
    ConversationSummaryResponseModelDirection,
    ConversationSummaryResponseModelStatus,
    ConversationTokenDbModel,
    ConversationTokenPurpose,
    ConversationTurnMetrics,
    ConversationalConfig,
    ConvertChapterResponseModel,
    ConvertProjectResponseModel,
    CreateAgentResponseModel,
    CreateAudioNativeProjectRequest,
    CreatePhoneNumberResponseModel,
    CreatePreviouslyGeneratedVoiceRequest,
    CreatePronunciationDictionaryResponseModel,
    CreateSipTrunkPhoneNumberRequest,
    CreateTranscriptRequest,
    CreateTwilioPhoneNumberRequest,
    CustomLlm,
    CustomLlmRequestHeadersValue,
    DashboardCallSuccessChartModel,
    DashboardCriteriaChartModel,
    DashboardDataCollectionChartModel,
    DataCollectionResultCommonModel,
    DeleteChapterRequest,
    DeleteChapterResponseModel,
    DeleteDubbingResponseModel,
    DeleteHistoryItemResponse,
    DeleteProjectRequest,
    DeleteProjectResponseModel,
    DeleteSampleResponse,
    DeleteVoiceResponseModel,
    DeleteVoiceSampleResponseModel,
    DeleteWorkspaceGroupMemberResponseModel,
    DeleteWorkspaceInviteResponseModel,
    DeleteWorkspaceMemberResponseModel,
    DependentAvailableAgentIdentifier,
    DependentAvailableAgentIdentifierAccessLevel,
    DependentAvailableToolIdentifier,
    DependentAvailableToolIdentifierAccessLevel,
    DependentPhoneNumberIdentifier,
    DependentUnknownAgentIdentifier,
    DependentUnknownToolIdentifier,
    DialogueInput,
    DialogueInputResponseModel,
    DoDubbingResponse,
    DocumentUsageModeEnum,
    DocxExportOptions,
    DubbedSegment,
    DubbingMediaMetadata,
    DubbingMediaReference,
    DubbingMetadataPageResponseModel,
    DubbingMetadataResponse,
    DubbingRenderResponseModel,
    DubbingResource,
    DynamicVariableAssignment,
    DynamicVariableUpdateCommonModel,
    DynamicVariablesConfig,
    DynamicVariablesConfigDynamicVariablePlaceholdersValue,
    EditChapterResponseModel,
    EditProjectResponseModel,
    EditVoiceResponseModel,
    EditVoiceSettingsRequest,
    EditVoiceSettingsResponseModel,
    EmbedVariant,
    EmbeddingModelEnum,
    EndCallToolConfig,
    EndCallToolResultModel,
    EvaluationSettings,
    EvaluationSuccessResult,
    ExportOptions,
    ExportOptions_Docx,
    ExportOptions_Html,
    ExportOptions_Pdf,
    ExportOptions_SegmentedJson,
    ExportOptions_Srt,
    ExportOptions_Txt,
    ExtendedSubscriptionResponseModelBillingPeriod,
    ExtendedSubscriptionResponseModelCharacterRefreshPeriod,
    ExtendedSubscriptionResponseModelCurrency,
    FeatureStatusCommonModel,
    FeaturesUsageCommonModel,
    FeedbackItem,
    FinalOutput,
    FinalOutputMulti,
    FineTuningResponse,
    FineTuningResponseModelStateValue,
    FlushContext,
    ForcedAlignmentCharacterResponseModel,
    ForcedAlignmentResponseModel,
    ForcedAlignmentWordResponseModel,
    Gender,
    GenerateVoiceRequest,
    GenerationConfig,
    GetAgentEmbedResponseModel,
    GetAgentKnowledgebaseSizeResponseModel,
    GetAgentLinkResponseModel,
    GetAgentResponseModel,
    GetAgentResponseModelPhoneNumbersItem,
    GetAgentResponseModelPhoneNumbersItem_SipTrunk,
    GetAgentResponseModelPhoneNumbersItem_Twilio,
    GetAgentsPageResponseModel,
    GetAudioNativeProjectSettingsResponseModel,
    GetChapterRequest,
    GetChapterSnapshotsRequest,
    GetChaptersRequest,
    GetChaptersResponse,
    GetConvAiDashboardSettingsResponseModel,
    GetConvAiDashboardSettingsResponseModelChartsItem,
    GetConvAiDashboardSettingsResponseModelChartsItem_CallSuccess,
    GetConvAiDashboardSettingsResponseModelChartsItem_Criteria,
    GetConvAiDashboardSettingsResponseModelChartsItem_DataCollection,
    GetConvAiSettingsResponseModel,
    GetConversationResponseModel,
    GetConversationResponseModelStatus,
    GetConversationsPageResponseModel,
    GetKnowledgeBaseDependentAgentsResponseModel,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available,
    GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown,
    GetKnowledgeBaseFileResponseModel,
    GetKnowledgeBaseListResponseModel,
    GetKnowledgeBaseListResponseModelDocumentsItem,
    GetKnowledgeBaseListResponseModelDocumentsItem_File,
    GetKnowledgeBaseListResponseModelDocumentsItem_Text,
    GetKnowledgeBaseListResponseModelDocumentsItem_Url,
    GetKnowledgeBaseSummaryFileResponseModel,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown,
    GetKnowledgeBaseSummaryTextResponseModel,
    GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Unknown,
    GetKnowledgeBaseSummaryUrlResponseModel,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available,
    GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown,
    GetKnowledgeBaseTextResponseModel,
    GetKnowledgeBaseUrlResponseModel,
    GetLibraryVoicesResponse,
    GetPhoneNumberInboundSipTrunkConfigResponseModel,
    GetPhoneNumberOutboundSipTrunkConfigResponseModel,
    GetPhoneNumberResponse,
    GetPhoneNumberSipTrunkResponseModel,
    GetPhoneNumberTwilioResponseModel,
    GetProjectRequest,
    GetProjectsRequest,
    GetProjectsResponse,
    GetPronunciationDictionariesMetadataResponseModel,
    GetPronunciationDictionariesResponse,
    GetPronunciationDictionaryMetadataResponse,
    GetPronunciationDictionaryMetadataResponseModelPermissionOnResource,
    GetPronunciationDictionaryResponse,
    GetSpeechHistoryResponse,
    GetToolDependentAgentsResponseModel,
    GetToolDependentAgentsResponseModelAgentsItem,
    GetToolDependentAgentsResponseModelAgentsItem_Available,
    GetToolDependentAgentsResponseModelAgentsItem_Unknown,
    GetVoicesResponse,
    GetVoicesV2Response,
    GetWorkspaceSecretsResponseModel,
    HistoryAlignmentResponseModel,
    HistoryAlignmentsResponseModel,
    HistoryItemResponse,
    HtmlExportOptions,
    HttpValidationError,
    ImageAvatar,
    InboundSipTrunkConfigRequestModel,
    InitialiseContext,
    InitializeConnection,
    InitializeConnectionMulti,
    IntegrationType,
    InvoiceResponse,
    KeepContextAlive,
    KnowledgeBaseDocumentChunkResponseModel,
    KnowledgeBaseDocumentMetadataResponseModel,
    KnowledgeBaseDocumentType,
    KnowledgeBaseLocator,
    LanguageAddedResponse,
    LanguageDetectionToolConfig,
    LanguageDetectionToolResultModel,
    LanguagePresetInput,
    LanguagePresetOutput,
    LanguagePresetTranslation,
    LanguageResponse,
    LibraryVoiceResponse,
    LibraryVoiceResponseModelCategory,
    ListMcpToolsResponseModel,
    LiteralJsonSchemaProperty,
    LiteralJsonSchemaPropertyConstantValue,
    LiteralJsonSchemaPropertyType,
    Llm,
    LlmCategoryUsage,
    LlmInputOutputTokensUsage,
    LlmTokensCategoryUsage,
    LlmUsageCalculatorLlmResponseModel,
    LlmUsageCalculatorResponseModel,
    LlmUsageInput,
    LlmUsageOutput,
    ManualVerificationFileResponse,
    ManualVerificationResponse,
    McpApprovalPolicy,
    McpServerConfigInput,
    McpServerConfigInputRequestHeadersValue,
    McpServerConfigInputSecretToken,
    McpServerConfigInputUrl,
    McpServerConfigOutput,
    McpServerConfigOutputRequestHeadersValue,
    McpServerConfigOutputSecretToken,
    McpServerConfigOutputUrl,
    McpServerMetadataResponseModel,
    McpServerResponseModel,
    McpServerResponseModelDependentAgentsItem,
    McpServerResponseModelDependentAgentsItem_Available,
    McpServerResponseModelDependentAgentsItem_Unknown,
    McpServerTransport,
    McpServersResponseModel,
    McpToolApprovalHash,
    McpToolApprovalPolicy,
    MetricRecord,
    MetricType,
    Model,
    ModelRatesResponseModel,
    ModelResponseModelConcurrencyGroup,
    ModelSettingsResponseModel,
    ModerationStatusResponseModel,
    ModerationStatusResponseModelSafetyStatus,
    ModerationStatusResponseModelWarningStatus,
    MultichannelSpeechToTextResponseModel,
    MusicPrompt,
    NormalizedAlignment,
    ObjectJsonSchemaPropertyInput,
    ObjectJsonSchemaPropertyInputPropertiesValue,
    ObjectJsonSchemaPropertyOutput,
    ObjectJsonSchemaPropertyOutputPropertiesValue,
    OrbAvatar,
    OutboundCallRecipient,
    OutboundCallRecipientResponseModel,
    OutboundSipTrunkConfigRequestModel,
    OutputFormat,
    PdfExportOptions,
    PhoneNumberAgentInfo,
    PhoneNumberTransfer,
    PhoneNumberTransferDestination,
    PhoneNumberTransferTransferDestination,
    PhoneNumberTransferTransferDestination_Phone,
    PhoneNumberTransferTransferDestination_SipUri,
    PlayDtmfResultErrorModel,
    PlayDtmfResultSuccessModel,
    PlayDtmfToolConfig,
    PodcastBulletinMode,
    PodcastBulletinModeData,
    PodcastConversationMode,
    PodcastConversationModeData,
    PodcastProjectResponseModel,
    PodcastTextSource,
    PodcastUrlSource,
    PostAgentAvatarResponseModel,
    PostWorkspaceSecretResponseModel,
    PrivacyConfig,
    ProjectCreationMetaResponseModel,
    ProjectCreationMetaResponseModelStatus,
    ProjectCreationMetaResponseModelType,
    ProjectExtendedResponse,
    ProjectExtendedResponseModelAccessLevel,
    ProjectExtendedResponseModelApplyTextNormalization,
    ProjectExtendedResponseModelFiction,
    ProjectExtendedResponseModelQualityPreset,
    ProjectExtendedResponseModelSourceType,
    ProjectExtendedResponseModelTargetAudience,
    ProjectResponse,
    ProjectResponseModelAccessLevel,
    ProjectResponseModelFiction,
    ProjectResponseModelSourceType,
    ProjectResponseModelTargetAudience,
    ProjectSnapshotExtendedResponseModel,
    ProjectSnapshotResponse,
    ProjectSnapshotsResponse,
    ProjectState,
    PromptAgent,
    PromptAgentApiModelInput,
    PromptAgentApiModelInputToolsItem,
    PromptAgentApiModelInputToolsItem_Client,
    PromptAgentApiModelInputToolsItem_Mcp,
    PromptAgentApiModelInputToolsItem_System,
    PromptAgentApiModelInputToolsItem_Webhook,
    PromptAgentApiModelOutput,
    PromptAgentApiModelOutputToolsItem,
    PromptAgentApiModelOutputToolsItem_Client,
    PromptAgentApiModelOutputToolsItem_Mcp,
    PromptAgentApiModelOutputToolsItem_System,
    PromptAgentApiModelOutputToolsItem_Webhook,
    PromptAgentApiModelOverride,
    PromptAgentApiModelOverrideConfig,
    PromptAgentDbModel,
    PromptEvaluationCriteria,
    PronunciationDictionaryAliasRuleRequestModel,
    PronunciationDictionaryLocator,
    PronunciationDictionaryLocatorResponseModel,
    PronunciationDictionaryPhonemeRuleRequestModel,
    PronunciationDictionaryRulesResponseModel,
    PronunciationDictionaryVersionLocator,
    PronunciationDictionaryVersionResponseModel,
    PronunciationDictionaryVersionResponseModelPermissionOnResource,
    PydanticPronunciationDictionaryVersionLocator,
    QueryParamsJsonSchema,
    RagChunkMetadata,
    RagConfig,
    RagDocumentIndexResponseModel,
    RagDocumentIndexUsage,
    RagDocumentIndexesResponseModel,
    RagIndexOverviewEmbeddingModelResponseModel,
    RagIndexOverviewResponseModel,
    RagIndexStatus,
    RagRetrievalInfo,
    ReaderResourceResponseModel,
    ReaderResourceResponseModelResourceType,
    RealtimeVoiceSettings,
    RecordingResponse,
    RemoveMemberFromGroupRequest,
    Render,
    RenderStatus,
    RenderType,
    RequestPvcManualVerificationResponseModel,
    ResourceAccessInfo,
    ResourceAccessInfoRole,
    ResourceMetadataResponseModel,
    ReviewStatus,
    SafetyCommonModel,
    SafetyEvaluation,
    SafetyResponseModel,
    SafetyRule,
    SaveVoicePreviewRequest,
    SecretDependencyType,
    SegmentCreateResponse,
    SegmentDeleteResponse,
    SegmentDubResponse,
    SegmentSubtitleFrame,
    SegmentTranscriptionResponse,
    SegmentTranslationResponse,
    SegmentUpdateResponse,
    SegmentedJsonExportOptions,
    SendText,
    SendTextMulti,
    ShareOptionResponseModel,
    ShareOptionResponseModelType,
    SimilarVoice,
    SimilarVoiceCategory,
    SimilarVoicesForSpeakerResponse,
    SipMediaEncryptionEnum,
    SipTrunkCredentialsRequestModel,
    SipTrunkOutboundCallResponse,
    SipTrunkTransportEnum,
    SipUriTransferDestination,
    SkipTurnToolConfig,
    SkipTurnToolResponseModel,
    SongSection,
    SpeakerAudioResponseModel,
    SpeakerResponseModel,
    SpeakerSegment,
    SpeakerSeparationResponseModel,
    SpeakerSeparationResponseModelStatus,
    SpeakerTrack,
    SpeakerUpdatedResponse,
    SpeechHistoryItemResponse,
    SpeechHistoryItemResponseModelSource,
    SpeechHistoryItemResponseModelVoiceCategory,
    SpeechToTextCharacterResponseModel,
    SpeechToTextChunkResponseModel,
    SpeechToTextWebhookResponseModel,
    SpeechToTextWordResponseModel,
    SpeechToTextWordResponseModelType,
    SrtExportOptions,
    StartPvcVoiceTrainingResponseModel,
    StartSpeakerSeparationResponseModel,
    StreamingAudioChunkWithTimestampsResponse,
    Subscription,
    SubscriptionExtrasResponseModel,
    SubscriptionResponse,
    SubscriptionResponseModelBillingPeriod,
    SubscriptionResponseModelCharacterRefreshPeriod,
    SubscriptionResponseModelCurrency,
    SubscriptionStatusType,
    SubscriptionUsageResponseModel,
    SupportedVoice,
    SystemToolConfigInput,
    SystemToolConfigInputParams,
    SystemToolConfigInputParams_EndCall,
    SystemToolConfigInputParams_LanguageDetection,
    SystemToolConfigInputParams_PlayKeypadTouchTone,
    SystemToolConfigInputParams_SkipTurn,
    SystemToolConfigInputParams_TransferToAgent,
    SystemToolConfigInputParams_TransferToNumber,
    SystemToolConfigInputParams_VoicemailDetection,
    SystemToolConfigOutput,
    SystemToolConfigOutputParams,
    SystemToolConfigOutputParams_EndCall,
    SystemToolConfigOutputParams_LanguageDetection,
    SystemToolConfigOutputParams_PlayKeypadTouchTone,
    SystemToolConfigOutputParams_SkipTurn,
    SystemToolConfigOutputParams_TransferToAgent,
    SystemToolConfigOutputParams_TransferToNumber,
    SystemToolConfigOutputParams_VoicemailDetection,
    TelephonyProvider,
    TextToSpeechApplyTextNormalizationEnum,
    TextToSpeechOutputFormatEnum,
    TextToSpeechStreamRequest,
    TokenResponseModel,
    Tool,
    ToolAnnotations,
    ToolMockConfig,
    ToolRequestModel,
    ToolRequestModelToolConfig,
    ToolRequestModelToolConfig_Client,
    ToolRequestModelToolConfig_Mcp,
    ToolRequestModelToolConfig_System,
    ToolRequestModelToolConfig_Webhook,
    ToolResponseModel,
    ToolResponseModelToolConfig,
    ToolResponseModelToolConfig_Client,
    ToolResponseModelToolConfig_Mcp,
    ToolResponseModelToolConfig_System,
    ToolResponseModelToolConfig_Webhook,
    ToolType,
    ToolUsageStatsResponseModel,
    ToolsResponseModel,
    TransferToAgentToolConfig,
    TransferToAgentToolResultErrorModel,
    TransferToAgentToolResultSuccessModel,
    TransferToNumberResultErrorModel,
    TransferToNumberResultSipSuccessModel,
    TransferToNumberResultTwilioSuccessModel,
    TransferToNumberToolConfigInput,
    TransferToNumberToolConfigOutput,
    TransferTypeEnum,
    TtsConversationalConfigInput,
    TtsConversationalConfigOutput,
    TtsConversationalConfigOverride,
    TtsConversationalConfigOverrideConfig,
    TtsConversationalModel,
    TtsModelFamily,
    TtsOptimizeStreamingLatency,
    TtsOutputFormat,
    TurnConfig,
    TurnMode,
    TwilioOutboundCallResponse,
    TxtExportOptions,
    UpdateAudioNativeProjectRequest,
    UpdateChapterRequest,
    UpdateProjectRequest,
    UpdatePronunciationDictionariesRequest,
    UpdateWorkspaceMemberResponseModel,
    UrlAvatar,
    UsageAggregationInterval,
    UsageCharactersResponseModel,
    User,
    UserFeedback,
    UserFeedbackScore,
    UtteranceResponseModel,
    ValidationError,
    ValidationErrorLocItem,
    VerificationAttemptResponse,
    VerifiedVoiceLanguageResponseModel,
    VerifyPvcVoiceCaptchaResponseModel,
    Voice,
    VoiceDesignPreviewResponse,
    VoiceGenerationParameterOptionResponse,
    VoiceGenerationParameterResponse,
    VoiceMailDetectionResultSuccessModel,
    VoicePreviewResponseModel,
    VoiceResponseModelCategory,
    VoiceResponseModelSafetyControl,
    VoiceSample,
    VoiceSamplePreviewResponseModel,
    VoiceSampleVisualWaveformResponseModel,
    VoiceSettings,
    VoiceSharingModerationCheckResponseModel,
    VoiceSharingResponse,
    VoiceSharingResponseModelCategory,
    VoiceSharingState,
    VoiceVerificationResponse,
    VoicemailDetectionToolConfig,
    WebhookAuthMethodType,
    WebhookToolApiSchemaConfigInput,
    WebhookToolApiSchemaConfigInputMethod,
    WebhookToolApiSchemaConfigInputRequestHeadersValue,
    WebhookToolApiSchemaConfigOutput,
    WebhookToolApiSchemaConfigOutputMethod,
    WebhookToolApiSchemaConfigOutputRequestHeadersValue,
    WebhookToolConfigInput,
    WebhookToolConfigOutput,
    WebhookUsageType,
    WebsocketTtsClientMessageMulti,
    WebsocketTtsServerMessageMulti,
    WidgetConfig,
    WidgetConfigInputAvatar,
    WidgetConfigInputAvatar_Image,
    WidgetConfigInputAvatar_Orb,
    WidgetConfigInputAvatar_Url,
    WidgetConfigOutputAvatar,
    WidgetConfigOutputAvatar_Image,
    WidgetConfigOutputAvatar_Orb,
    WidgetConfigOutputAvatar_Url,
    WidgetConfigResponse,
    WidgetConfigResponseModelAvatar,
    WidgetConfigResponseModelAvatar_Image,
    WidgetConfigResponseModelAvatar_Orb,
    WidgetConfigResponseModelAvatar_Url,
    WidgetExpandable,
    WidgetFeedbackMode,
    WidgetLanguagePreset,
    WidgetLanguagePresetResponse,
    WidgetPlacement,
    WidgetStyles,
    WidgetTextContents,
    WorkflowToolEdgeStepModel,
    WorkflowToolMaxIterationsExceededStepModel,
    WorkflowToolNestedToolsStepModelInput,
    WorkflowToolNestedToolsStepModelInputResultsItem,
    WorkflowToolNestedToolsStepModelOutput,
    WorkflowToolNestedToolsStepModelOutputResultsItem,
    WorkflowToolResponseModelInput,
    WorkflowToolResponseModelInputStepsItem,
    WorkflowToolResponseModelInputStepsItem_Edge,
    WorkflowToolResponseModelInputStepsItem_MaxIterationsExceeded,
    WorkflowToolResponseModelInputStepsItem_NestedTools,
    WorkflowToolResponseModelOutput,
    WorkflowToolResponseModelOutputStepsItem,
    WorkflowToolResponseModelOutputStepsItem_Edge,
    WorkflowToolResponseModelOutputStepsItem_MaxIterationsExceeded,
    WorkflowToolResponseModelOutputStepsItem_NestedTools,
    WorkspaceApiKeyListResponseModel,
    WorkspaceApiKeyResponseModel,
    WorkspaceApiKeyResponseModelPermissionsItem,
    WorkspaceBatchCallsResponse,
    WorkspaceCreateApiKeyResponseModel,
    WorkspaceGroupByNameResponseModel,
    WorkspaceResourceType,
    WorkspaceServiceAccountListResponseModel,
    WorkspaceServiceAccountResponseModel,
    WorkspaceWebhookListResponseModel,
    WorkspaceWebhookResponseModel,
    WorkspaceWebhookUsageResponseModel,
)
from .errors import BadRequestError, ForbiddenError, NotFoundError, TooEarlyError, UnprocessableEntityError
from . import (
    audio_isolation,
    audio_native,
    conversational_ai,
    dubbing,
    forced_alignment,
    history,
    models,
    music,
    pronunciation_dictionaries,
    samples,
    service_accounts,
    speech_to_speech,
    speech_to_text,
    studio,
    text_to_dialogue,
    text_to_sound_effects,
    text_to_speech,
    text_to_voice,
    usage,
    user,
    v_1_text_to_speech_voice_id_multi_stream_input,
    v_1_text_to_speech_voice_id_stream_input,
    voices,
    webhooks,
    workspace,
)
from .audio_isolation import AudioIsolationConvertRequestFileFormat, AudioIsolationStreamRequestFileFormat
from .client import AsyncElevenLabs, ElevenLabs
from .dubbing import DubbingListRequestDubbingStatus, DubbingListRequestFilterByCreator
from .environment import ElevenLabsEnvironment
from .history import HistoryListRequestSource
from .music import (
    MusicComposeDetailedRequestOutputFormat,
    MusicComposeRequestOutputFormat,
    MusicStreamRequestOutputFormat,
)
from .play import play, save, stream
from .pronunciation_dictionaries import (
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme,
    BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess,
    PronunciationDictionariesCreateFromFileRequestWorkspaceAccess,
    PronunciationDictionariesListRequestSort,
)
from .speech_to_speech import (
    SpeechToSpeechConvertRequestFileFormat,
    SpeechToSpeechConvertRequestOutputFormat,
    SpeechToSpeechStreamRequestFileFormat,
    SpeechToSpeechStreamRequestOutputFormat,
)
from .speech_to_text import (
    SpeechToTextConvertRequestFileFormat,
    SpeechToTextConvertRequestTimestampsGranularity,
    SpeechToTextConvertRequestWebhookMetadata,
    SpeechToTextConvertResponse,
)
from .studio import (
    BodyCreatePodcastV1StudioPodcastsPostDurationScale,
    BodyCreatePodcastV1StudioPodcastsPostMode,
    BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin,
    BodyCreatePodcastV1StudioPodcastsPostMode_Conversation,
    BodyCreatePodcastV1StudioPodcastsPostQualityPreset,
    BodyCreatePodcastV1StudioPodcastsPostSource,
    BodyCreatePodcastV1StudioPodcastsPostSourceItem,
    BodyCreatePodcastV1StudioPodcastsPostSourceItem_Text,
    BodyCreatePodcastV1StudioPodcastsPostSourceItem_Url,
)
from .text_to_dialogue import TextToDialogueConvertRequestOutputFormat, TextToDialogueStreamRequestOutputFormat
from .text_to_sound_effects import TextToSoundEffectsConvertRequestOutputFormat
from .text_to_speech import (
    BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization,
    BodyTextToSpeechStreamingWithTimestampsV1TextToSpeechVoiceIdStreamWithTimestampsPostApplyTextNormalization,
    BodyTextToSpeechV1TextToSpeechVoiceIdPostApplyTextNormalization,
    BodyTextToSpeechWithTimestampsV1TextToSpeechVoiceIdWithTimestampsPostApplyTextNormalization,
    TextToSpeechConvertRequestOutputFormat,
    TextToSpeechConvertWithTimestampsRequestOutputFormat,
    TextToSpeechStreamRequestOutputFormat,
    TextToSpeechStreamWithTimestampsRequestOutputFormat,
)
from .text_to_voice import (
    TextToVoiceCreatePreviewsRequestOutputFormat,
    TextToVoiceDesignRequestOutputFormat,
    VoiceDesignRequestModelModelId,
)
from .v_1_text_to_speech_voice_id_multi_stream_input import ReceiveMessageMulti, SendMessageMulti
from .v_1_text_to_speech_voice_id_stream_input import ReceiveMessage, SendMessage
from .version import __version__
from .voices import VoicesGetSharedRequestCategory

__all__ = [
    "AddChapterResponseModel",
    "AddKnowledgeBaseResponseModel",
    "AddProjectRequest",
    "AddProjectResponseModel",
    "AddPronunciationDictionaryResponseModel",
    "AddPronunciationDictionaryResponseModelPermissionOnResource",
    "AddSharingVoiceRequest",
    "AddVoiceIvcResponseModel",
    "AddVoiceResponseModel",
    "AddWorkspaceGroupMemberResponseModel",
    "AddWorkspaceInviteResponseModel",
    "AdditionalFormatResponseModel",
    "AdditionalFormats",
    "Age",
    "AgentCallLimits",
    "AgentConfig",
    "AgentConfigOverride",
    "AgentConfigOverrideConfig",
    "AgentMetadataResponseModel",
    "AgentPlatformSettingsRequestModel",
    "AgentPlatformSettingsResponseModel",
    "AgentSimulatedChatTestResponseModel",
    "AgentSummaryResponseModel",
    "AgentTestingSettings",
    "AgentTransfer",
    "AgentWorkspaceOverridesInput",
    "AgentWorkspaceOverridesOutput",
    "Alignment",
    "AllowlistItem",
    "ArrayJsonSchemaPropertyInput",
    "ArrayJsonSchemaPropertyInputItems",
    "ArrayJsonSchemaPropertyOutput",
    "ArrayJsonSchemaPropertyOutputItems",
    "AsrConversationalConfig",
    "AsrInputFormat",
    "AsrProvider",
    "AsrQuality",
    "AsyncElevenLabs",
    "AudioIsolationConvertRequestFileFormat",
    "AudioIsolationStreamRequestFileFormat",
    "AudioNativeCreateProjectResponseModel",
    "AudioNativeEditContentResponseModel",
    "AudioNativeProjectSettingsResponseModel",
    "AudioNativeProjectSettingsResponseModelStatus",
    "AudioOutput",
    "AudioOutputMulti",
    "AudioWithTimestampsResponse",
    "AuthConnectionLocator",
    "AuthSettings",
    "AuthorizationMethod",
    "BadRequestError",
    "BadRequestErrorBody",
    "BanReasonType",
    "BatchCallDetailedResponse",
    "BatchCallRecipientStatus",
    "BatchCallResponse",
    "BatchCallStatus",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Alias",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostRulesItem_Phoneme",
    "BodyAddAPronunciationDictionaryV1PronunciationDictionariesAddFromRulesPostWorkspaceAccess",
    "BodyCreatePodcastV1StudioPodcastsPostDurationScale",
    "BodyCreatePodcastV1StudioPodcastsPostMode",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Bulletin",
    "BodyCreatePodcastV1StudioPodcastsPostMode_Conversation",
    "BodyCreatePodcastV1StudioPodcastsPostQualityPreset",
    "BodyCreatePodcastV1StudioPodcastsPostSource",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem_Text",
    "BodyCreatePodcastV1StudioPodcastsPostSourceItem_Url",
    "BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostAge",
    "BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostGender",
    "BodyTextToSpeechStreamingV1TextToSpeechVoiceIdStreamPostApplyTextNormalization",
    "BodyTextToSpeechStreamingWithTimestampsV1TextToSpeechVoiceIdStreamWithTimestampsPostApplyTextNormalization",
    "BodyTextToSpeechV1TextToSpeechVoiceIdPostApplyTextNormalization",
    "BodyTextToSpeechWithTimestampsV1TextToSpeechVoiceIdWithTimestampsPostApplyTextNormalization",
    "BreakdownTypes",
    "BuiltInToolsInput",
    "BuiltInToolsOutput",
    "CaptionStyleCharacterAnimationModel",
    "CaptionStyleCharacterAnimationModelEnterType",
    "CaptionStyleCharacterAnimationModelExitType",
    "CaptionStyleHorizontalPlacementModel",
    "CaptionStyleHorizontalPlacementModelAlign",
    "CaptionStyleModel",
    "CaptionStyleModelTextAlign",
    "CaptionStyleModelTextStyle",
    "CaptionStyleModelTextWeight",
    "CaptionStyleSectionAnimationModel",
    "CaptionStyleSectionAnimationModelEnterType",
    "CaptionStyleSectionAnimationModelExitType",
    "CaptionStyleTemplateModel",
    "CaptionStyleVerticalPlacementModel",
    "CaptionStyleVerticalPlacementModelAlign",
    "CaptionStyleWordAnimationModel",
    "CaptionStyleWordAnimationModelEnterType",
    "CaptionStyleWordAnimationModelExitType",
    "ChapterContentBlockExtendableNodeResponseModel",
    "ChapterContentBlockInputModel",
    "ChapterContentBlockInputModelSubType",
    "ChapterContentBlockResponseModel",
    "ChapterContentBlockResponseModelNodesItem",
    "ChapterContentBlockResponseModelNodesItem_Other",
    "ChapterContentBlockResponseModelNodesItem_TtsNode",
    "ChapterContentBlockTtsNodeResponseModel",
    "ChapterContentInputModel",
    "ChapterContentParagraphTtsNodeInputModel",
    "ChapterContentResponseModel",
    "ChapterResponse",
    "ChapterSnapshotExtendedResponseModel",
    "ChapterSnapshotResponse",
    "ChapterSnapshotsResponse",
    "ChapterState",
    "ChapterStatisticsResponse",
    "ChapterWithContentResponseModel",
    "ChapterWithContentResponseModelState",
    "CharacterAlignmentModel",
    "CharacterAlignmentResponseModel",
    "CharacterUsageResponse",
    "ClientEvent",
    "ClientToolConfigInput",
    "ClientToolConfigOutput",
    "CloseConnection",
    "CloseContext",
    "CloseSocket",
    "ConvAiDynamicVariable",
    "ConvAiSecretLocator",
    "ConvAiStoredSecretDependencies",
    "ConvAiStoredSecretDependenciesAgentsItem",
    "ConvAiStoredSecretDependenciesAgentsItem_Available",
    "ConvAiStoredSecretDependenciesAgentsItem_Unknown",
    "ConvAiStoredSecretDependenciesToolsItem",
    "ConvAiStoredSecretDependenciesToolsItem_Available",
    "ConvAiStoredSecretDependenciesToolsItem_Unknown",
    "ConvAiUserSecretDbModel",
    "ConvAiWebhooks",
    "ConvAiWorkspaceStoredSecretConfig",
    "ConversationChargingCommonModel",
    "ConversationConfig",
    "ConversationConfigClientOverrideConfigInput",
    "ConversationConfigClientOverrideConfigOutput",
    "ConversationConfigClientOverrideInput",
    "ConversationConfigClientOverrideOutput",
    "ConversationConfigOverride",
    "ConversationConfigOverrideConfig",
    "ConversationDeletionSettings",
    "ConversationHistoryAnalysisCommonModel",
    "ConversationHistoryBatchCallModel",
    "ConversationHistoryElevenAssistantCommonModel",
    "ConversationHistoryErrorCommonModel",
    "ConversationHistoryEvaluationCriteriaResultCommonModel",
    "ConversationHistoryFeedbackCommonModel",
    "ConversationHistoryMetadataCommonModel",
    "ConversationHistoryMetadataCommonModelPhoneCall",
    "ConversationHistoryMetadataCommonModelPhoneCall_SipTrunking",
    "ConversationHistoryMetadataCommonModelPhoneCall_Twilio",
    "ConversationHistoryRagUsageCommonModel",
    "ConversationHistorySipTrunkingPhoneCallModel",
    "ConversationHistorySipTrunkingPhoneCallModelDirection",
    "ConversationHistoryTranscriptCommonModelInput",
    "ConversationHistoryTranscriptCommonModelInputRole",
    "ConversationHistoryTranscriptCommonModelInputSourceMedium",
    "ConversationHistoryTranscriptCommonModelInputToolResultsItem",
    "ConversationHistoryTranscriptCommonModelOutput",
    "ConversationHistoryTranscriptCommonModelOutputRole",
    "ConversationHistoryTranscriptCommonModelOutputSourceMedium",
    "ConversationHistoryTranscriptCommonModelOutputToolResultsItem",
    "ConversationHistoryTranscriptOtherToolsResultCommonModel",
    "ConversationHistoryTranscriptOtherToolsResultCommonModelType",
    "ConversationHistoryTranscriptSystemToolResultCommonModel",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_EndCallSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_LanguageDetectionSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_PlayDtmfSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_SkipTurnSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToAgentSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberError",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberSipSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_TransferToNumberTwilioSuccess",
    "ConversationHistoryTranscriptSystemToolResultCommonModelResult_VoicemailDetectionSuccess",
    "ConversationHistoryTranscriptToolCallClientDetails",
    "ConversationHistoryTranscriptToolCallCommonModel",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails_Client",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails_Mcp",
    "ConversationHistoryTranscriptToolCallCommonModelToolDetails_Webhook",
    "ConversationHistoryTranscriptToolCallMcpDetails",
    "ConversationHistoryTranscriptToolCallWebhookDetails",
    "ConversationHistoryTranscriptWorkflowToolsResultCommonModelInput",
    "ConversationHistoryTranscriptWorkflowToolsResultCommonModelOutput",
    "ConversationHistoryTwilioPhoneCallModel",
    "ConversationHistoryTwilioPhoneCallModelDirection",
    "ConversationInitiationClientDataConfigInput",
    "ConversationInitiationClientDataConfigOutput",
    "ConversationInitiationClientDataInternal",
    "ConversationInitiationClientDataInternalDynamicVariablesValue",
    "ConversationInitiationClientDataRequestInput",
    "ConversationInitiationClientDataRequestInputDynamicVariablesValue",
    "ConversationInitiationClientDataRequestOutput",
    "ConversationInitiationClientDataRequestOutputDynamicVariablesValue",
    "ConversationInitiationClientDataWebhook",
    "ConversationInitiationClientDataWebhookRequestHeadersValue",
    "ConversationInitiationSource",
    "ConversationInitiationSourceInfo",
    "ConversationSignedUrlResponseModel",
    "ConversationSimulationSpecification",
    "ConversationSimulationSpecificationDynamicVariablesValue",
    "ConversationSummaryResponseModel",
    "ConversationSummaryResponseModelDirection",
    "ConversationSummaryResponseModelStatus",
    "ConversationTokenDbModel",
    "ConversationTokenPurpose",
    "ConversationTurnMetrics",
    "ConversationalConfig",
    "ConvertChapterResponseModel",
    "ConvertProjectResponseModel",
    "CreateAgentResponseModel",
    "CreateAudioNativeProjectRequest",
    "CreatePhoneNumberResponseModel",
    "CreatePreviouslyGeneratedVoiceRequest",
    "CreatePronunciationDictionaryResponseModel",
    "CreateSipTrunkPhoneNumberRequest",
    "CreateTranscriptRequest",
    "CreateTwilioPhoneNumberRequest",
    "CustomLlm",
    "CustomLlmRequestHeadersValue",
    "DashboardCallSuccessChartModel",
    "DashboardCriteriaChartModel",
    "DashboardDataCollectionChartModel",
    "DataCollectionResultCommonModel",
    "DeleteChapterRequest",
    "DeleteChapterResponseModel",
    "DeleteDubbingResponseModel",
    "DeleteHistoryItemResponse",
    "DeleteProjectRequest",
    "DeleteProjectResponseModel",
    "DeleteSampleResponse",
    "DeleteVoiceResponseModel",
    "DeleteVoiceSampleResponseModel",
    "DeleteWorkspaceGroupMemberResponseModel",
    "DeleteWorkspaceInviteResponseModel",
    "DeleteWorkspaceMemberResponseModel",
    "DependentAvailableAgentIdentifier",
    "DependentAvailableAgentIdentifierAccessLevel",
    "DependentAvailableToolIdentifier",
    "DependentAvailableToolIdentifierAccessLevel",
    "DependentPhoneNumberIdentifier",
    "DependentUnknownAgentIdentifier",
    "DependentUnknownToolIdentifier",
    "DialogueInput",
    "DialogueInputResponseModel",
    "DoDubbingResponse",
    "DocumentUsageModeEnum",
    "DocxExportOptions",
    "DubbedSegment",
    "DubbingListRequestDubbingStatus",
    "DubbingListRequestFilterByCreator",
    "DubbingMediaMetadata",
    "DubbingMediaReference",
    "DubbingMetadataPageResponseModel",
    "DubbingMetadataResponse",
    "DubbingRenderResponseModel",
    "DubbingResource",
    "DynamicVariableAssignment",
    "DynamicVariableUpdateCommonModel",
    "DynamicVariablesConfig",
    "DynamicVariablesConfigDynamicVariablePlaceholdersValue",
    "EditChapterResponseModel",
    "EditProjectResponseModel",
    "EditVoiceResponseModel",
    "EditVoiceSettingsRequest",
    "EditVoiceSettingsResponseModel",
    "ElevenLabs",
    "ElevenLabsEnvironment",
    "EmbedVariant",
    "EmbeddingModelEnum",
    "EndCallToolConfig",
    "EndCallToolResultModel",
    "EvaluationSettings",
    "EvaluationSuccessResult",
    "ExportOptions",
    "ExportOptions_Docx",
    "ExportOptions_Html",
    "ExportOptions_Pdf",
    "ExportOptions_SegmentedJson",
    "ExportOptions_Srt",
    "ExportOptions_Txt",
    "ExtendedSubscriptionResponseModelBillingPeriod",
    "ExtendedSubscriptionResponseModelCharacterRefreshPeriod",
    "ExtendedSubscriptionResponseModelCurrency",
    "FeatureStatusCommonModel",
    "FeaturesUsageCommonModel",
    "FeedbackItem",
    "FinalOutput",
    "FinalOutputMulti",
    "FineTuningResponse",
    "FineTuningResponseModelStateValue",
    "FlushContext",
    "ForbiddenError",
    "ForcedAlignmentCharacterResponseModel",
    "ForcedAlignmentResponseModel",
    "ForcedAlignmentWordResponseModel",
    "Gender",
    "GenerateVoiceRequest",
    "GenerationConfig",
    "GetAgentEmbedResponseModel",
    "GetAgentKnowledgebaseSizeResponseModel",
    "GetAgentLinkResponseModel",
    "GetAgentResponseModel",
    "GetAgentResponseModelPhoneNumbersItem",
    "GetAgentResponseModelPhoneNumbersItem_SipTrunk",
    "GetAgentResponseModelPhoneNumbersItem_Twilio",
    "GetAgentsPageResponseModel",
    "GetAudioNativeProjectSettingsResponseModel",
    "GetChapterRequest",
    "GetChapterSnapshotsRequest",
    "GetChaptersRequest",
    "GetChaptersResponse",
    "GetConvAiDashboardSettingsResponseModel",
    "GetConvAiDashboardSettingsResponseModelChartsItem",
    "GetConvAiDashboardSettingsResponseModelChartsItem_CallSuccess",
    "GetConvAiDashboardSettingsResponseModelChartsItem_Criteria",
    "GetConvAiDashboardSettingsResponseModelChartsItem_DataCollection",
    "GetConvAiSettingsResponseModel",
    "GetConversationResponseModel",
    "GetConversationResponseModelStatus",
    "GetConversationsPageResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModel",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Available",
    "GetKnowledgeBaseDependentAgentsResponseModelAgentsItem_Unknown",
    "GetKnowledgeBaseFileResponseModel",
    "GetKnowledgeBaseListResponseModel",
    "GetKnowledgeBaseListResponseModelDocumentsItem",
    "GetKnowledgeBaseListResponseModelDocumentsItem_File",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Text",
    "GetKnowledgeBaseListResponseModelDocumentsItem_Url",
    "GetKnowledgeBaseSummaryFileResponseModel",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryFileResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryTextResponseModel",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryTextResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseSummaryUrlResponseModel",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Available",
    "GetKnowledgeBaseSummaryUrlResponseModelDependentAgentsItem_Unknown",
    "GetKnowledgeBaseTextResponseModel",
    "GetKnowledgeBaseUrlResponseModel",
    "GetLibraryVoicesResponse",
    "GetPhoneNumberInboundSipTrunkConfigResponseModel",
    "GetPhoneNumberOutboundSipTrunkConfigResponseModel",
    "GetPhoneNumberResponse",
    "GetPhoneNumberSipTrunkResponseModel",
    "GetPhoneNumberTwilioResponseModel",
    "GetProjectRequest",
    "GetProjectsRequest",
    "GetProjectsResponse",
    "GetPronunciationDictionariesMetadataResponseModel",
    "GetPronunciationDictionariesResponse",
    "GetPronunciationDictionaryMetadataResponse",
    "GetPronunciationDictionaryMetadataResponseModelPermissionOnResource",
    "GetPronunciationDictionaryResponse",
    "GetSpeechHistoryResponse",
    "GetToolDependentAgentsResponseModel",
    "GetToolDependentAgentsResponseModelAgentsItem",
    "GetToolDependentAgentsResponseModelAgentsItem_Available",
    "GetToolDependentAgentsResponseModelAgentsItem_Unknown",
    "GetVoicesResponse",
    "GetVoicesV2Response",
    "GetWorkspaceSecretsResponseModel",
    "HistoryAlignmentResponseModel",
    "HistoryAlignmentsResponseModel",
    "HistoryItemResponse",
    "HistoryListRequestSource",
    "HtmlExportOptions",
    "HttpValidationError",
    "ImageAvatar",
    "InboundSipTrunkConfigRequestModel",
    "InitialiseContext",
    "InitializeConnection",
    "InitializeConnectionMulti",
    "IntegrationType",
    "InvoiceResponse",
    "KeepContextAlive",
    "KnowledgeBaseDocumentChunkResponseModel",
    "KnowledgeBaseDocumentMetadataResponseModel",
    "KnowledgeBaseDocumentType",
    "KnowledgeBaseLocator",
    "LanguageAddedResponse",
    "LanguageDetectionToolConfig",
    "LanguageDetectionToolResultModel",
    "LanguagePresetInput",
    "LanguagePresetOutput",
    "LanguagePresetTranslation",
    "LanguageResponse",
    "LibraryVoiceResponse",
    "LibraryVoiceResponseModelCategory",
    "ListMcpToolsResponseModel",
    "LiteralJsonSchemaProperty",
    "LiteralJsonSchemaPropertyConstantValue",
    "LiteralJsonSchemaPropertyType",
    "Llm",
    "LlmCategoryUsage",
    "LlmInputOutputTokensUsage",
    "LlmTokensCategoryUsage",
    "LlmUsageCalculatorLlmResponseModel",
    "LlmUsageCalculatorResponseModel",
    "LlmUsageInput",
    "LlmUsageOutput",
    "ManualVerificationFileResponse",
    "ManualVerificationResponse",
    "McpApprovalPolicy",
    "McpServerConfigInput",
    "McpServerConfigInputRequestHeadersValue",
    "McpServerConfigInputSecretToken",
    "McpServerConfigInputUrl",
    "McpServerConfigOutput",
    "McpServerConfigOutputRequestHeadersValue",
    "McpServerConfigOutputSecretToken",
    "McpServerConfigOutputUrl",
    "McpServerMetadataResponseModel",
    "McpServerResponseModel",
    "McpServerResponseModelDependentAgentsItem",
    "McpServerResponseModelDependentAgentsItem_Available",
    "McpServerResponseModelDependentAgentsItem_Unknown",
    "McpServerTransport",
    "McpServersResponseModel",
    "McpToolApprovalHash",
    "McpToolApprovalPolicy",
    "MetricRecord",
    "MetricType",
    "Model",
    "ModelRatesResponseModel",
    "ModelResponseModelConcurrencyGroup",
    "ModelSettingsResponseModel",
    "ModerationStatusResponseModel",
    "ModerationStatusResponseModelSafetyStatus",
    "ModerationStatusResponseModelWarningStatus",
    "MultichannelSpeechToTextResponseModel",
    "MusicComposeDetailedRequestOutputFormat",
    "MusicComposeRequestOutputFormat",
    "MusicPrompt",
    "MusicStreamRequestOutputFormat",
    "NormalizedAlignment",
    "NotFoundError",
    "ObjectJsonSchemaPropertyInput",
    "ObjectJsonSchemaPropertyInputPropertiesValue",
    "ObjectJsonSchemaPropertyOutput",
    "ObjectJsonSchemaPropertyOutputPropertiesValue",
    "OrbAvatar",
    "OutboundCallRecipient",
    "OutboundCallRecipientResponseModel",
    "OutboundSipTrunkConfigRequestModel",
    "OutputFormat",
    "PdfExportOptions",
    "PhoneNumberAgentInfo",
    "PhoneNumberTransfer",
    "PhoneNumberTransferDestination",
    "PhoneNumberTransferTransferDestination",
    "PhoneNumberTransferTransferDestination_Phone",
    "PhoneNumberTransferTransferDestination_SipUri",
    "PlayDtmfResultErrorModel",
    "PlayDtmfResultSuccessModel",
    "PlayDtmfToolConfig",
    "PodcastBulletinMode",
    "PodcastBulletinModeData",
    "PodcastConversationMode",
    "PodcastConversationModeData",
    "PodcastProjectResponseModel",
    "PodcastTextSource",
    "PodcastUrlSource",
    "PostAgentAvatarResponseModel",
    "PostWorkspaceSecretResponseModel",
    "PrivacyConfig",
    "ProjectCreationMetaResponseModel",
    "ProjectCreationMetaResponseModelStatus",
    "ProjectCreationMetaResponseModelType",
    "ProjectExtendedResponse",
    "ProjectExtendedResponseModelAccessLevel",
    "ProjectExtendedResponseModelApplyTextNormalization",
    "ProjectExtendedResponseModelFiction",
    "ProjectExtendedResponseModelQualityPreset",
    "ProjectExtendedResponseModelSourceType",
    "ProjectExtendedResponseModelTargetAudience",
    "ProjectResponse",
    "ProjectResponseModelAccessLevel",
    "ProjectResponseModelFiction",
    "ProjectResponseModelSourceType",
    "ProjectResponseModelTargetAudience",
    "ProjectSnapshotExtendedResponseModel",
    "ProjectSnapshotResponse",
    "ProjectSnapshotsResponse",
    "ProjectState",
    "PromptAgent",
    "PromptAgentApiModelInput",
    "PromptAgentApiModelInputToolsItem",
    "PromptAgentApiModelInputToolsItem_Client",
    "PromptAgentApiModelInputToolsItem_Mcp",
    "PromptAgentApiModelInputToolsItem_System",
    "PromptAgentApiModelInputToolsItem_Webhook",
    "PromptAgentApiModelOutput",
    "PromptAgentApiModelOutputToolsItem",
    "PromptAgentApiModelOutputToolsItem_Client",
    "PromptAgentApiModelOutputToolsItem_Mcp",
    "PromptAgentApiModelOutputToolsItem_System",
    "PromptAgentApiModelOutputToolsItem_Webhook",
    "PromptAgentApiModelOverride",
    "PromptAgentApiModelOverrideConfig",
    "PromptAgentDbModel",
    "PromptEvaluationCriteria",
    "PronunciationDictionariesCreateFromFileRequestWorkspaceAccess",
    "PronunciationDictionariesListRequestSort",
    "PronunciationDictionaryAliasRuleRequestModel",
    "PronunciationDictionaryLocator",
    "PronunciationDictionaryLocatorResponseModel",
    "PronunciationDictionaryPhonemeRuleRequestModel",
    "PronunciationDictionaryRulesResponseModel",
    "PronunciationDictionaryVersionLocator",
    "PronunciationDictionaryVersionResponseModel",
    "PronunciationDictionaryVersionResponseModelPermissionOnResource",
    "PydanticPronunciationDictionaryVersionLocator",
    "QueryParamsJsonSchema",
    "RagChunkMetadata",
    "RagConfig",
    "RagDocumentIndexResponseModel",
    "RagDocumentIndexUsage",
    "RagDocumentIndexesResponseModel",
    "RagIndexOverviewEmbeddingModelResponseModel",
    "RagIndexOverviewResponseModel",
    "RagIndexStatus",
    "RagRetrievalInfo",
    "ReaderResourceResponseModel",
    "ReaderResourceResponseModelResourceType",
    "RealtimeVoiceSettings",
    "ReceiveMessage",
    "ReceiveMessageMulti",
    "RecordingResponse",
    "RemoveMemberFromGroupRequest",
    "Render",
    "RenderStatus",
    "RenderType",
    "RequestPvcManualVerificationResponseModel",
    "ResourceAccessInfo",
    "ResourceAccessInfoRole",
    "ResourceMetadataResponseModel",
    "ReviewStatus",
    "SafetyCommonModel",
    "SafetyEvaluation",
    "SafetyResponseModel",
    "SafetyRule",
    "SaveVoicePreviewRequest",
    "SecretDependencyType",
    "SegmentCreateResponse",
    "SegmentDeleteResponse",
    "SegmentDubResponse",
    "SegmentSubtitleFrame",
    "SegmentTranscriptionResponse",
    "SegmentTranslationResponse",
    "SegmentUpdateResponse",
    "SegmentedJsonExportOptions",
    "SendMessage",
    "SendMessageMulti",
    "SendText",
    "SendTextMulti",
    "ShareOptionResponseModel",
    "ShareOptionResponseModelType",
    "SimilarVoice",
    "SimilarVoiceCategory",
    "SimilarVoicesForSpeakerResponse",
    "SipMediaEncryptionEnum",
    "SipTrunkCredentialsRequestModel",
    "SipTrunkOutboundCallResponse",
    "SipTrunkTransportEnum",
    "SipUriTransferDestination",
    "SkipTurnToolConfig",
    "SkipTurnToolResponseModel",
    "SongSection",
    "SpeakerAudioResponseModel",
    "SpeakerResponseModel",
    "SpeakerSegment",
    "SpeakerSeparationResponseModel",
    "SpeakerSeparationResponseModelStatus",
    "SpeakerTrack",
    "SpeakerUpdatedResponse",
    "SpeechHistoryItemResponse",
    "SpeechHistoryItemResponseModelSource",
    "SpeechHistoryItemResponseModelVoiceCategory",
    "SpeechToSpeechConvertRequestFileFormat",
    "SpeechToSpeechConvertRequestOutputFormat",
    "SpeechToSpeechStreamRequestFileFormat",
    "SpeechToSpeechStreamRequestOutputFormat",
    "SpeechToTextCharacterResponseModel",
    "SpeechToTextChunkResponseModel",
    "SpeechToTextConvertRequestFileFormat",
    "SpeechToTextConvertRequestTimestampsGranularity",
    "SpeechToTextConvertRequestWebhookMetadata",
    "SpeechToTextConvertResponse",
    "SpeechToTextWebhookResponseModel",
    "SpeechToTextWordResponseModel",
    "SpeechToTextWordResponseModelType",
    "SrtExportOptions",
    "StartPvcVoiceTrainingResponseModel",
    "StartSpeakerSeparationResponseModel",
    "StreamingAudioChunkWithTimestampsResponse",
    "Subscription",
    "SubscriptionExtrasResponseModel",
    "SubscriptionResponse",
    "SubscriptionResponseModelBillingPeriod",
    "SubscriptionResponseModelCharacterRefreshPeriod",
    "SubscriptionResponseModelCurrency",
    "SubscriptionStatusType",
    "SubscriptionUsageResponseModel",
    "SupportedVoice",
    "SystemToolConfigInput",
    "SystemToolConfigInputParams",
    "SystemToolConfigInputParams_EndCall",
    "SystemToolConfigInputParams_LanguageDetection",
    "SystemToolConfigInputParams_PlayKeypadTouchTone",
    "SystemToolConfigInputParams_SkipTurn",
    "SystemToolConfigInputParams_TransferToAgent",
    "SystemToolConfigInputParams_TransferToNumber",
    "SystemToolConfigInputParams_VoicemailDetection",
    "SystemToolConfigOutput",
    "SystemToolConfigOutputParams",
    "SystemToolConfigOutputParams_EndCall",
    "SystemToolConfigOutputParams_LanguageDetection",
    "SystemToolConfigOutputParams_PlayKeypadTouchTone",
    "SystemToolConfigOutputParams_SkipTurn",
    "SystemToolConfigOutputParams_TransferToAgent",
    "SystemToolConfigOutputParams_TransferToNumber",
    "SystemToolConfigOutputParams_VoicemailDetection",
    "TelephonyProvider",
    "TextToDialogueConvertRequestOutputFormat",
    "TextToDialogueStreamRequestOutputFormat",
    "TextToSoundEffectsConvertRequestOutputFormat",
    "TextToSpeechApplyTextNormalizationEnum",
    "TextToSpeechConvertRequestOutputFormat",
    "TextToSpeechConvertWithTimestampsRequestOutputFormat",
    "TextToSpeechOutputFormatEnum",
    "TextToSpeechStreamRequest",
    "TextToSpeechStreamRequestOutputFormat",
    "TextToSpeechStreamWithTimestampsRequestOutputFormat",
    "TextToVoiceCreatePreviewsRequestOutputFormat",
    "TextToVoiceDesignRequestOutputFormat",
    "TokenResponseModel",
    "TooEarlyError",
    "Tool",
    "ToolAnnotations",
    "ToolMockConfig",
    "ToolRequestModel",
    "ToolRequestModelToolConfig",
    "ToolRequestModelToolConfig_Client",
    "ToolRequestModelToolConfig_Mcp",
    "ToolRequestModelToolConfig_System",
    "ToolRequestModelToolConfig_Webhook",
    "ToolResponseModel",
    "ToolResponseModelToolConfig",
    "ToolResponseModelToolConfig_Client",
    "ToolResponseModelToolConfig_Mcp",
    "ToolResponseModelToolConfig_System",
    "ToolResponseModelToolConfig_Webhook",
    "ToolType",
    "ToolUsageStatsResponseModel",
    "ToolsResponseModel",
    "TransferToAgentToolConfig",
    "TransferToAgentToolResultErrorModel",
    "TransferToAgentToolResultSuccessModel",
    "TransferToNumberResultErrorModel",
    "TransferToNumberResultSipSuccessModel",
    "TransferToNumberResultTwilioSuccessModel",
    "TransferToNumberToolConfigInput",
    "TransferToNumberToolConfigOutput",
    "TransferTypeEnum",
    "TtsConversationalConfigInput",
    "TtsConversationalConfigOutput",
    "TtsConversationalConfigOverride",
    "TtsConversationalConfigOverrideConfig",
    "TtsConversationalModel",
    "TtsModelFamily",
    "TtsOptimizeStreamingLatency",
    "TtsOutputFormat",
    "TurnConfig",
    "TurnMode",
    "TwilioOutboundCallResponse",
    "TxtExportOptions",
    "UnprocessableEntityError",
    "UpdateAudioNativeProjectRequest",
    "UpdateChapterRequest",
    "UpdateProjectRequest",
    "UpdatePronunciationDictionariesRequest",
    "UpdateWorkspaceMemberResponseModel",
    "UrlAvatar",
    "UsageAggregationInterval",
    "UsageCharactersResponseModel",
    "User",
    "UserFeedback",
    "UserFeedbackScore",
    "UtteranceResponseModel",
    "ValidationError",
    "ValidationErrorLocItem",
    "VerificationAttemptResponse",
    "VerifiedVoiceLanguageResponseModel",
    "VerifyPvcVoiceCaptchaResponseModel",
    "Voice",
    "VoiceDesignPreviewResponse",
    "VoiceDesignRequestModelModelId",
    "VoiceGenerationParameterOptionResponse",
    "VoiceGenerationParameterResponse",
    "VoiceMailDetectionResultSuccessModel",
    "VoicePreviewResponseModel",
    "VoiceResponseModelCategory",
    "VoiceResponseModelSafetyControl",
    "VoiceSample",
    "VoiceSamplePreviewResponseModel",
    "VoiceSampleVisualWaveformResponseModel",
    "VoiceSettings",
    "VoiceSharingModerationCheckResponseModel",
    "VoiceSharingResponse",
    "VoiceSharingResponseModelCategory",
    "VoiceSharingState",
    "VoiceVerificationResponse",
    "VoicemailDetectionToolConfig",
    "VoicesGetSharedRequestCategory",
    "WebhookAuthMethodType",
    "WebhookToolApiSchemaConfigInput",
    "WebhookToolApiSchemaConfigInputMethod",
    "WebhookToolApiSchemaConfigInputRequestHeadersValue",
    "WebhookToolApiSchemaConfigOutput",
    "WebhookToolApiSchemaConfigOutputMethod",
    "WebhookToolApiSchemaConfigOutputRequestHeadersValue",
    "WebhookToolConfigInput",
    "WebhookToolConfigOutput",
    "WebhookUsageType",
    "WebsocketTtsClientMessageMulti",
    "WebsocketTtsServerMessageMulti",
    "WidgetConfig",
    "WidgetConfigInputAvatar",
    "WidgetConfigInputAvatar_Image",
    "WidgetConfigInputAvatar_Orb",
    "WidgetConfigInputAvatar_Url",
    "WidgetConfigOutputAvatar",
    "WidgetConfigOutputAvatar_Image",
    "WidgetConfigOutputAvatar_Orb",
    "WidgetConfigOutputAvatar_Url",
    "WidgetConfigResponse",
    "WidgetConfigResponseModelAvatar",
    "WidgetConfigResponseModelAvatar_Image",
    "WidgetConfigResponseModelAvatar_Orb",
    "WidgetConfigResponseModelAvatar_Url",
    "WidgetExpandable",
    "WidgetFeedbackMode",
    "WidgetLanguagePreset",
    "WidgetLanguagePresetResponse",
    "WidgetPlacement",
    "WidgetStyles",
    "WidgetTextContents",
    "WorkflowToolEdgeStepModel",
    "WorkflowToolMaxIterationsExceededStepModel",
    "WorkflowToolNestedToolsStepModelInput",
    "WorkflowToolNestedToolsStepModelInputResultsItem",
    "WorkflowToolNestedToolsStepModelOutput",
    "WorkflowToolNestedToolsStepModelOutputResultsItem",
    "WorkflowToolResponseModelInput",
    "WorkflowToolResponseModelInputStepsItem",
    "WorkflowToolResponseModelInputStepsItem_Edge",
    "WorkflowToolResponseModelInputStepsItem_MaxIterationsExceeded",
    "WorkflowToolResponseModelInputStepsItem_NestedTools",
    "WorkflowToolResponseModelOutput",
    "WorkflowToolResponseModelOutputStepsItem",
    "WorkflowToolResponseModelOutputStepsItem_Edge",
    "WorkflowToolResponseModelOutputStepsItem_MaxIterationsExceeded",
    "WorkflowToolResponseModelOutputStepsItem_NestedTools",
    "WorkspaceApiKeyListResponseModel",
    "WorkspaceApiKeyResponseModel",
    "WorkspaceApiKeyResponseModelPermissionsItem",
    "WorkspaceBatchCallsResponse",
    "WorkspaceCreateApiKeyResponseModel",
    "WorkspaceGroupByNameResponseModel",
    "WorkspaceResourceType",
    "WorkspaceServiceAccountListResponseModel",
    "WorkspaceServiceAccountResponseModel",
    "WorkspaceWebhookListResponseModel",
    "WorkspaceWebhookResponseModel",
    "WorkspaceWebhookUsageResponseModel",
    "__version__",
    "audio_isolation",
    "audio_native",
    "conversational_ai",
    "dubbing",
    "forced_alignment",
    "history",
    "models",
    "music",
    "play",
    "pronunciation_dictionaries",
    "samples",
    "save",
    "service_accounts",
    "speech_to_speech",
    "speech_to_text",
    "stream",
    "studio",
    "text_to_dialogue",
    "text_to_sound_effects",
    "text_to_speech",
    "text_to_voice",
    "usage",
    "user",
    "v_1_text_to_speech_voice_id_multi_stream_input",
    "v_1_text_to_speech_voice_id_stream_input",
    "voices",
    "webhooks",
    "workspace",
]
