# This file was auto-generated by Fern from our API Definition.

import typing

ConversationHistorySipTrunkingPhoneCallModelDirection = typing.Union[typing.Literal["inbound", "outbound"], typing.Any]
