# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .body_share_workspace_resource_v_1_workspace_resources_resource_id_share_post_role import (
    BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole,
)

__all__ = ["BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole"]
