# This file was auto-generated by Fern from our API Definition.

import typing

from .body_create_service_account_api_key_v_1_service_accounts_service_account_user_id_api_keys_post_permissions_item import (
    BodyCreateServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysPostPermissionsItem,
)

BodyCreateServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysPostPermissions = typing.Union[
    typing.List[BodyCreateServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysPostPermissionsItem],
    typing.Literal["all"],
]
