# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .resources import BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole
from . import groups, invites, members, resources
from .invites import BodyInviteUserV1WorkspaceInvitesAddPostWorkspacePermission
from .members import BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole

__all__ = [
    "BodyInviteUserV1WorkspaceInvitesAddPostWorkspacePermission",
    "BodyShareWorkspaceResourceV1WorkspaceResourcesResourceIdSharePostRole",
    "BodyUpdateMemberV1WorkspaceMembersPostWorkspaceRole",
    "groups",
    "invites",
    "members",
    "resources",
]
