# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import BodyInviteUserV1WorkspaceInvitesAddPostWorkspacePermission

__all__ = ["BodyInviteUserV1WorkspaceInvitesAddPostWorkspacePermission"]
