# This file was auto-generated by Fern from our API Definition.

import typing

ProjectResponseModelSourceType = typing.Union[typing.Literal["blank", "book", "article", "genfm", "video"], typing.Any]
