# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .voices_get_shared_request_category import VoicesGetSharedRequestCategory

__all__ = ["VoicesGetSharedRequestCategory"]
