# This file was auto-generated by Fern from our API Definition.

import typing

from .conv_ai_dynamic_variable import ConvAiDynamicVariable
from .conv_ai_secret_locator import ConvAiSecretLocator

WebhookToolApiSchemaConfigInputRequestHeadersValue = typing.Union[str, ConvAiSecretLocator, ConvAiDynamicVariable]
