# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .documents_get_response import (
    DocumentsGetResponse,
    DocumentsGetResponse_File,
    DocumentsGetResponse_Text,
    DocumentsGetResponse_Url,
)
from .documents_update_response import (
    DocumentsUpdateResponse,
    DocumentsUpdateResponse_File,
    DocumentsUpdateResponse_Text,
    DocumentsUpdateResponse_Url,
)

__all__ = [
    "DocumentsGetResponse",
    "DocumentsGetResponse_File",
    "DocumentsGetResponse_Text",
    "DocumentsGetResponse_Url",
    "DocumentsUpdateResponse",
    "DocumentsUpdateResponse_File",
    "DocumentsUpdateResponse_Text",
    "DocumentsUpdateResponse_Url",
]
