# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .projects_create_request_apply_text_normalization import ProjectsCreateRequestApplyTextNormalization
from .projects_create_request_fiction import ProjectsCreateRequestFiction
from .projects_create_request_source_type import ProjectsCreateRequestSourceType
from .projects_create_request_target_audience import ProjectsCreateRequestTargetAudience

__all__ = [
    "ProjectsCreateRequestApplyTextNormalization",
    "ProjectsCreateRequestFiction",
    "ProjectsCreateRequestSourceType",
    "ProjectsCreateRequestTargetAudience",
]
