# This file was auto-generated by Fern from our API Definition.

import typing

BodyGenerateARandomVoiceV1VoiceGenerationGenerateVoicePostAge = typing.Union[
    typing.Literal["young", "middle_aged", "old"], typing.Any
]
