# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    SpeechToTextConvertRequestFileFormat,
    SpeechToTextConvertRequestTimestampsGranularity,
    SpeechToTextConvertRequestWebhookMetadata,
    SpeechToTextConvertResponse,
)

__all__ = [
    "SpeechToTextConvertRequestFileFormat",
    "SpeechToTextConvertRequestTimestampsGranularity",
    "SpeechToTextConvertRequestWebhookMetadata",
    "SpeechToTextConvertResponse",
]
