# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .speech_to_text_convert_request_file_format import SpeechToTextConvertRequestFileFormat
from .speech_to_text_convert_request_timestamps_granularity import SpeechToTextConvertRequestTimestampsGranularity
from .speech_to_text_convert_request_webhook_metadata import SpeechToTextConvertRequestWebhookMetadata
from .speech_to_text_convert_response import SpeechToTextConvertResponse

__all__ = [
    "SpeechToTextConvertRequestFileFormat",
    "SpeechToTextConvertRequestTimestampsGranularity",
    "SpeechToTextConvertRequestWebhookMetadata",
    "SpeechToTextConvertResponse",
]
