# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .body_invite_user_v_1_workspace_invites_add_post_workspace_permission import (
    BodyInviteUserV1WorkspaceInvitesAddPostWorkspacePermission,
)

__all__ = ["BodyInviteUserV1WorkspaceInvitesAddPostWorkspacePermission"]
