# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    SpeechToSpeechConvertRequestFileFormat,
    SpeechToSpeechConvertRequestOutputFormat,
    SpeechToSpeechStreamRequestFileFormat,
    SpeechToSpeechStreamRequestOutputFormat,
)

__all__ = [
    "SpeechToSpeechConvertRequestFileFormat",
    "SpeechToSpeechConvertRequestOutputFormat",
    "SpeechToSpeechStreamRequestFileFormat",
    "SpeechToSpeechStreamRequestOutputFormat",
]
